Attribute VB_Name = "UniDAQ"
'//-----------------------------------------------------------------------------------------
'//File Name:UniDAQ.bas
'//Update date:2014/02/13 by Dan Huang
'//Support Language: Visual Basic 6.0
'//UniDAQ SDK User Manual: http://ftp.icpdas.com/pub/cd/iocard/pci/napdos/pci/unidaq/maunal/
'//-----------------------------------------------------------------------------------------

Option Explicit

Global Const MAX_BOARD_NUMBER = 32
Global Const MAX_EVENT_NUMBER = 20
Global Const MAX_AO_CHANNEL = 32

'//Option Mode
Global Const MULTIPROCESSOR = 1
Global Const ENABLEMEMIO = 2
Global Const ENABLEDMAAI = 16

'ModelNumber
Global Const PIOD56 = &H800140
Global Const PEXD56 = &H800140
Global Const PIOD48 = &H800130
Global Const PEXD48 = &H800130
Global Const PIOD64 = &H800120
Global Const PIOD96 = &H800110
Global Const PIOD144 = &H800100
Global Const PIOD168 = &H800150
Global Const PIODA = &H800400
Global Const PEXDA = &H800400
Global Const PIO821 = &H800310

Global Const PISOP16R16U = &H1800FF
Global Const PEXP16R16 = &H1800FF
Global Const PEXP8R8 = &H1800FF
Global Const PISOC64 = &H800800
Global Const PEXC64 = &H800800
Global Const PISOP64 = &H800810
Global Const PEXP64 = &H800810
Global Const PISOA64 = &H800850
Global Const PISOP32C32 = &H800820
Global Const PEXP32C32 = &H800820
Global Const PISOP32A32 = &H800870
Global Const PISOP8R8 = &H800830
Global Const PISO730 = &H800840
Global Const PISO730A = &H800880
Global Const PISO725 = &H8008FF
Global Const PISODA2 = &H800B00

Global Const PISO813 = &H800A00

Global Const PCITMC12 = &HDF2962
Global Const PCIM512 = &HDE9562
Global Const PCIM256 = &HDE92A6
Global Const PCIM128 = &HDE9178
Global Const PCIFC16 = &HB13017
Global Const PCID64 = &HDE3513


Global Const PCI822 = &HDE3823
Global Const PCI826 = &HDE3827
Global Const PCI827 = &HDE3828
Global Const PCI2602 = &H2CB656
Global Const PCI100x = &H341002
Global Const PEX100x = &H341002
Global Const PCI1202 = &H345672
Global Const PEX1202 = &H345672
Global Const PCI1602 = &H345676
Global Const PCI180x = &H345678
Global Const PCIP8R8 = &HD6102B
Global Const PEXP8POR8 = &HD6102B
Global Const PCIP16R16 = &HD61E39
Global Const PEXP16POR16 = &HD61E39

Global Const MAX_CFGCODE_NUMBER = 24

'User Config Code
Global Const IXUD_BI_20V = 23     'Bipolar +/- 20V
Global Const IXUD_BI_10V = 0      'Bipolar +/- 10V
Global Const IXUD_BI_5V = 1       'Bipolar +/-  5V
Global Const IXUD_BI_2V5 = 2      'Bipolar +/-  2.5V
Global Const IXUD_BI_1V25 = 3     'Bipolar +/-  1.25V
Global Const IXUD_BI_0V625 = 4    'Bipolar +/-  0.625V
Global Const IXUD_BI_0V3125 = 5   'Bipolar +/-  0.3125V
Global Const IXUD_BI_0V5 = 6      'Bipolar +/-  0.5V
Global Const IXUD_BI_0V05 = 7     'Bipolar +/-  0.05V
Global Const IXUD_BI_0V005 = 8    'Bipolar +/-  0.005V
Global Const IXUD_BI_1V = 9       'Bipolar +/-  1V
Global Const IXUD_BI_0V1 = 10     'Bipolar +/-  0.1V
Global Const IXUD_BI_0V01 = 11    'Bipolar +/-  0.01V
Global Const IXUD_BI_0V001 = 12   'Bipolar +/-  0.001V
Global Const IXUD_UNI_20V = 13    'Unipolar 0 ~ 20V
Global Const IXUD_UNI_10V = 14    'Unipolar 0 ~ 10V
Global Const IXUD_UNI_5V = 15     'Unipolar 0 ~  5V
Global Const IXUD_UNI_2V5 = 16    'Unipolar 0 ~  2.5V
Global Const IXUD_UNI_1V25 = 17   'Unipolar 0 ~  1.25V
Global Const IXUD_UNI_0V625 = 18  'Unipolar 0 ~  0.625V
Global Const IXUD_UNI_1V = 19     'Unipolar 0 ~  1V
Global Const IXUD_UNI_0V1 = 20    'Unipolar 0 ~  0.1V
Global Const IXUD_UNI_0V01 = 21   'Unipolar 0 ~  0.01V
Global Const IXUD_UNI_0V001 = 22  'Unipolar 0 ~  0.001V


'//User AO Config Code for Voltage
Global Const IXUD_AO_UNI_5V = 0       'Unipolar 0  ~  5V
Global Const IXUD_AO_BI_5V = 1        'Bipolar  +/-   5V
Global Const IXUD_AO_UNI_10V = 2      'Unipolar 0  ~ 10V
Global Const IXUD_AO_BI_10V = 3       'Bipolar +/-  10V
Global Const IXUD_AO_UNI_20V = 4      'Unipolar 0  ~ 20V
Global Const IXUD_AO_BI_20V = 5       'Bipolar +/-  20V

'//User AO Config Code for Current
Global Const IXUD_AO_I_0_20MA = 16     '0 ~ 20mA
Global Const IXUD_AO_I_4_20MA = 17     '4 ~ 20mA

'//Interrupt Setting
Global Const IXUD_HARDWARE_INT = 1 'Hardware Interrupt
Global Const IXUD_APC_READY_INT = 2 'APC Ready Interrupt
Global Const IXUD_ACTIVE_LOW = 4   'Active Low Trigger
Global Const IXUD_ACTIVE_HIGH = 8  'Active High Trigger

'//Analog Trigger Mode Setting
Global Const IXUD_ANALOGTRIGGER_ABOVE = 1  '//Above high
Global Const IXUD_ANALOGTRIGGER_BELOW = 2  '//Below low
Global Const IXUD_ANALOGTRIGGER_INSIDE = 3 '//Inside region
Global Const IXUD_ANALOGTRIGGER_OUTSIDE = 4 '//Outside region

'// Return code
Global Const Ixud_NoErr = 0  '//Correct
Global Const Ixud_OpenDriverErr = 1  '//Open driver error
Global Const Ixud_PnPDriverErr = 2  '//Plug & Play error
Global Const Ixud_DriverNoOpen = 3  '//The driver was not open
Global Const Ixud_GetDriverVersionErr = 4  '//Recieve driver version error
Global Const Ixud_ExceedBoardNumber = 5  '//Board number error
Global Const Ixud_FindBoardErr = 6  '//No board found
Global Const Ixud_BoardMappingErr = 7  '//Board Mapping error
Global Const Ixud_DIOModesErr = 8  '//Digital input/output mode setting error
Global Const Ixud_InvalidAddress = 9  '//Invalid address
Global Const Ixud_InvalidSize = 10  '//Invalid size
Global Const Ixud_InvalidPortNumber = 11  '//Invalid port number
Global Const Ixud_UnSupportedModel = 12  '//This board model is not supported
Global Const Ixud_UnSupportedFun = 13  '//This function is not supported
Global Const Ixud_InvalidChannelNumber = 14  '//Invalid channel number
Global Const Ixud_InvalidValue = 15  '//Invalid value
Global Const Ixud_InvalidMode = 16  '//Invalid mode
Global Const Ixud_GetAIStatusTimeOut = 17  '//A timeout occurred while receiving the status of the analog input
Global Const Ixud_TimeOutErr = 18  '//Timeout error
Global Const Ixud_CfgCodeIndexErr = 19  '//A compatible configuration code table index could not be found
Global Const Ixud_ADCCTLTimeoutErr = 20  '//ADC controller a timeout error
Global Const Ixud_FindPCIIndexErr = 21  '//A compatible PCI table index value could not be found
Global Const Ixud_InvalidSetting = 22  '//Invalid setting value
Global Const Ixud_AllocateMemErr = 23  '//Error while allocating the memory space
Global Const Ixud_InstallEventErr = 24  '//Error while installing the interrupt event
Global Const Ixud_InstallIrqErr = 25  '//Error while installing the interrupt IRQ
Global Const Ixud_RemoveIrqErr = 26  '//Error while removing the interrupt IRQ
Global Const Ixud_ClearIntCountErr = 27  '//Error while the clear interrupt count
Global Const Ixud_GetSysBufferErr = 28  '//Error while retrieving the system buffer
Global Const Ixud_CreateEventErr = 29  '//Error while create the event
Global Const Ixud_UnSupportedResolution = 30  '//Resolution not supported
Global Const Ixud_CreateThreadErr = 31  '//Error while create the thread
Global Const Ixud_ThreadTimeOutErr = 32  '//Thread timeout error
Global Const Ixud_FIFOOverFlowErr = 33  '//FIFO overflow error
Global Const Ixud_FIFOTimeOutErr = 34  '//FIFO timeout error
Global Const Ixud_GetIntInstStatus = 35  '//Retrieves the status of the interrupt installation
Global Const Ixud_GetBufStatus = 36  '//Retrieves the status of the system buffer
Global Const Ixud_SetBufCountErr = 37  '//Error while setting the buffer count
Global Const Ixud_SetBufInfoErr = 38  '//Error while setting the buffer data
Global Const Ixud_FindCardIDErr = 39  '//Card ID code could not be found
Global Const Ixud_EventThreadErr = 40  '//Event Thread error
Global Const Ixud_AutoCreateEventErr = 41  '//Error while automatically creating an event
Global Const Ixud_RegThreadErr = 42  '//Register Thread error
Global Const Ixud_SearchEventErr = 43  '//Search Event error
Global Const Ixud_FifoResetErr = 44  '//Error while resetting the FIFO
Global Const Ixud_InvalidBlock = 45  '//Invalid EEPROM block
Global Const Ixud_InvalidAddr = 46  '//Invalid EEPROM address
Global Const Ixud_AcqireSpinLock = 47  '//Error while acquiring spin lock
Global Const Ixud_ReleaseSpinLock = 48  '//Error while releasing spin lock
Global Const Ixud_SetControlErr = 49  '//Analog input setting error
Global Const Ixud_InvalidChannels = 50  '//Invalid channel number
Global Const Ixud_SearchCardErr = 51  '//Invalid model number
Global Const Ixud_SetMapAddressErr = 52  '//Error while setting the mapping address
Global Const Ixud_ReleaseMapAddressErr = 53  '//Error while releasing the mapping address
Global Const Ixud_InvalidOffset = 54  '//Invalid memory offset
Global Const Ixud_ShareHandleErr = 55  '//Open the share memory fail
Global Const Ixud_InvalidDataCount = 56  '//Invalid data count
Global Const Ixud_WriteEEPErr = 57  '//Error while writing the EEPROM
Global Const Ixud_CardIOErr = 58  '//CardIO error
Global Const Ixud_IOErr = 59  '//MemoryIO error
Global Const Ixud_SetScanChannelErr = 60
Global Const Ixud_SetScanConfigErr = 61
Global Const Ixud_GetMMIOMapStatus = 62

Public Type IXUD_DEVICE_INFO
    AdwSize As Long
    
    wVendorID As Integer
    wDeviceID As Integer
    
    wSubVendorID As Integer
    wSubDeviceID As Integer
    dwBar(0 To 5)  As Long
   
    BusNo As Byte
    DevNo As Byte
    IRQ As Byte
    Aux As Byte
        
    dwBarVirtualAddress(0 To 5) As Long
End Type

Public Type IXUD_CARD_INFO
    dwSize As Long        'Structure size
    dwModelNo As Long         'Model Number
    
   'CardID is update when calling the function each time.
    CardID As Byte            'for new cards, =&hFF=N/A
    wSingleEnded As Byte   'for new cards,1:S.E 2:D.I.F,=&hFF=N/A
    wReserved As Integer      'Reserver

    wAIChannels As Integer    'Number of AI channels(AD)
    wAOChannels As Integer        'Number of AO channels(DA)

    wDIPorts As Integer           'Number of DI ports
    wDOPorts As Integer           'Number of DO ports

    wDIOPorts As Integer          'Number of DIO ports
    wDIOPortWidth As Integer      'The width is 8/16/32 bit.

    wCounterChannels As Integer   'Number of Timers/Counters
    wMemorySize As Integer        'PCI-M512==>512, Units in KB.

    dwReserved1(0 To 5) As Long  'Reserver
End Type


Declare Function Ixud_GetDllVersion Lib "UniDAQ.dll" (ByRef wDLLVer As Long) As Integer

'Driver functions
Declare Function Ixud_OptionMode Lib "UniDAQ.dll" (ByVal wMode As Long) As Integer
Declare Function Ixud_DriverInit Lib "UniDAQ.dll" (ByRef wTotalBoard As Integer) As Integer
Declare Function Ixud_DriverClose Lib "UniDAQ.dll" () As Integer
Declare Function Ixud_GetBoardNoByCardID Lib "UniDAQ.dll" (ByRef wBoardNo As Integer, ByVal dwModelNumber As Long, ByVal wCardID As Integer) As Integer
Declare Function Ixud_SearchCard Lib "UniDAQ.dll" (ByRef wTotalBoard As Integer, ByVal dwModelNo As Long) As Integer
Declare Function Ixud_GetCardInfo Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByRef sDevInfo As IXUD_DEVICE_INFO, ByRef sCardInfo As IXUD_CARD_INFO, ByVal szModelNmae As String) As Integer

'Declare Function    Ixud_GetDeviceInfo
Declare Function Ixud_ReadPort Lib "UniDAQ.dll" (ByVal dwAddress As Long, ByVal wSize As Integer, ByRef dwVal As Long) As Integer
Declare Function Ixud_WritePort Lib "UniDAQ.dll" (ByVal dwAddress As Long, ByVal wSize As Integer, ByVal dwVal As Long) As Integer
Declare Function Ixud_ReadPort32 Lib "UniDAQ.dll" (ByVal dwAddress As Long, ByVal wSize As Integer, ByRef dwLowVal As Long, ByRef dwHighVal As Long) As Integer
Declare Function Ixud_WritePort32 Lib "UniDAQ.dll" (ByVal dwAddress As Long, ByVal wSize As Integer, ByVal dwLowVal As Long, ByVal dwHighVal As Long) As Integer
Declare Function Ixud_ReadPhyMemory Lib "UniDAQ.dll" (ByVal dwAddress As Long, ByVal wSize As Integer, ByRef dwVal As Long) As Integer
Declare Function Ixud_WritePhyMemory Lib "UniDAQ.dll" (ByVal dwAddress As Long, ByVal wSize As Integer, ByVal dwVal As Long) As Integer
            
Declare Function Ixud_SetDIOModes32 Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal dwDioMode As Long) As Integer
Declare Function Ixud_SetDIOMode Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wPortNo As Integer, ByVal wDioMode As Integer) As Integer
Declare Function Ixud_ReadDI Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wPortNo As Integer, ByRef dwDIVal As Long) As Integer
Declare Function Ixud_WriteDO Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wPortNo As Integer, ByVal dwDOVal As Long) As Integer
Declare Function Ixud_ReadDI32 Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wPortNo As Integer, ByRef dwDILow As Long, ByRef dwDIHigh As Long) As Integer
Declare Function Ixud_WriteDO32 Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wPortNo As Integer, ByVal dwDOLow As Long, ByVal dwDOHigh As Long) As Integer
Declare Function Ixud_StartDI Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wPortNo As Integer, ByVal dwMode As Long, ByVal fSamplingRate As Single, ByVal dwDataCount As Long) As Integer
Declare Function Ixud_StopDI Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wPortNo As Integer) As Integer
Declare Function Ixud_GetDIBufferH Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wPortNo As Integer, ByVal dwDataCount As Long, ByRef hValue As Long) As Integer

Declare Function Ixud_StartDO Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wPortNo As Integer, ByVal dwMode As Long, ByVal fSamplingRate As Single, ByVal dwDataCount As Long, ByVal dwCycleNum As Long, ByRef dwDOVal As Long) As Integer
Declare Function Ixud_StopDO Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wPortNo As Integer) As Integer

Declare Function Ixud_SoftwareReadbackDO Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wPortNo As Integer, ByRef dwDOVal As Long) As Integer
Declare Function Ixud_SetPWMOutput Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wChannel As Integer, ByVal wMode As Integer, ByVal fFrequency As Single, ByVal fDutyRate As Single, ByVal fDelayUS As Single) As Integer

Declare Function Ixud_SetEventCallback Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wEventType As Integer, ByVal wInterruptSource As Integer, ByRef hEvent As Long, ByVal CallbackFun As Long, ByVal dwCallBackParameter As Long) As Integer
Declare Function Ixud_RemoveEventCallback Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wInterruptSource As Integer) As Integer

Declare Function Ixud_InstallIrq Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal dwInterruptMask As Long) As Integer
Declare Function Ixud_RemoveIrq Lib "UniDAQ.dll" (ByVal wBoardNo As Integer) As Integer


Declare Function Ixud_ReadCounter Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wChannel As Integer, ByRef dwValue As Long) As Integer
Declare Function Ixud_SetCounter Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wChannel As Integer, ByVal wMode As Integer, ByVal dwValue As Long) As Integer
Declare Function Ixud_DisableCounter Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wChannel As Integer) As Integer
Declare Function Ixud_SetFCChannelMode Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wChannel As Integer, ByVal wMode As Integer, ByVal wDelayMs As Integer) As Integer
Declare Function Ixud_ReadFrequency Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wChannel As Integer, ByRef fFrequency As Single, ByVal dwTimeOutMs As Long, ByRef wStatus As Integer) As Integer

Declare Function Ixud_ReadMemory Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal dwOffset As Long, ByVal Size As Integer, ByRef dwValue As Long) As Integer
Declare Function Ixud_WriteMemory Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal dwOffset As Long, ByVal Size As Integer, ByVal dwValue As Long) As Integer
Declare Function Ixud_ReadMemory32 Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal dwOffset As Long, ByRef dwLow As Long, ByRef dwHigh) As Integer
Declare Function Ixud_WriteMemory32 Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal dwOffset As Long, ByVal dwLow As Long, ByVal dwHigh) As Integer

Declare Function Ixud_ReadAI Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wChannel As Integer, ByVal wConfig As Integer, ByRef fValue As Single) As Integer
Declare Function Ixud_ReadAIH Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wChannel As Integer, ByVal wConfig As Integer, ByRef dwValue As Long) As Integer
Declare Function Ixud_PollingAI Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wChannel As Integer, ByVal wConfig As Integer, ByVal dwDataCount As Long, ByRef fValue As Single) As Integer
Declare Function Ixud_PollingAIH Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wChannel As Integer, ByVal wConfig As Integer, ByVal dwDataCount As Long, ByRef dwValue As Long) As Integer
Declare Function Ixud_PollingAIScan Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wChannels As Integer, ByRef wChannelList As Integer, ByRef wConfigList As Integer, ByVal dwDataCountPerChannel As Long, ByRef fValue As Single) As Integer
Declare Function Ixud_PollingAIScanH Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wChannels As Integer, ByRef wChannelList As Integer, ByRef wConfigList As Integer, ByVal dwDataCountPerChannel As Long, ByRef dwValue As Long) As Integer

Declare Function Ixud_ConfigAI Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wFIFOSizeKB As Integer, ByVal BufferSizeKB As Long, ByVal wCardType As Integer, ByVal wDelaySettlingTime As Integer) As Integer
Declare Function Ixud_ConfigAIEx Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wFIFOSizeKB As Integer, ByVal BufferSizeKB As Long, ByVal wCardType As Integer, ByVal wDelaySettlingTime As Integer, ByVal dwMode As Long) As Integer
Declare Function Ixud_ClearAIBuffer Lib "UniDAQ.dll" (ByVal wBoardNo As Integer) As Integer
Declare Function Ixud_GetBufferStatus Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByRef wBufferStatus As Integer, ByRef dwDataCount As Long) As Integer

Declare Function Ixud_StartAI Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wChannel As Integer, ByVal wConfig As Integer, ByVal fSamplingRate As Single, ByVal dwDataCount As Long) As Integer
Declare Function Ixud_StartAIScan Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wChannels As Integer, ByRef wChannelList As Integer, ByRef wConfigList As Integer, ByVal fSamplingRate As Single, ByVal dwDataCountPerChannel As Long) As Integer
Declare Function Ixud_StartExtAI Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wActive As Integer, ByVal wChannel As Integer, ByVal wConfig As Integer, ByVal fSamplingRate As Single, ByVal dwPostDataCount As Long, ByVal dwPreDataCount As Long) As Integer
Declare Function Ixud_StartExtAIScan Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wChannels As Integer, ByVal wActive As Integer, ByRef wChannelList As Integer, ByRef wConfigList As Integer, ByVal fSamplingRate As Single, ByVal dwPostDataCountPerChannel As Long, ByVal dwPreDataCountPerChannel As Long) As Integer
Declare Function Ixud_StartExtAnalogTrigger Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wActive As Integer, ByVal wChannel As Integer, ByVal wConfig As Integer, ByVal fSamplingRate As Single, ByVal dwPostDataCount As Long, ByVal dwReserved As Long, ByVal fAboveTrgVoltage As Single, ByVal fBelowTrgVoltage As Single) As Integer

Declare Function Ixud_GetAIBuffer Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal dwDataCount As Long, ByRef fValue As Single) As Integer
Declare Function Ixud_GetAIBufferH Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal dwDataCount As Long, ByRef hValue As Long) As Integer
Declare Function Ixud_StopAI Lib "UniDAQ.dll" (ByVal wBoardNo As Integer) As Integer

Declare Function Ixud_ConfigAO Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wChannel As Integer, ByVal wCfgCode As Integer) As Integer
Declare Function Ixud_WriteAOVoltage Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wChannel As Integer, ByVal fValue As Single) As Integer
Declare Function Ixud_WriteAOVoltageH Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wChannel As Integer, ByVal hValue As Long) As Integer
Declare Function Ixud_WriteAOCurrent Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wChannel As Integer, ByVal fValue As Single) As Integer
Declare Function Ixud_WriteAOCurrentH Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wChannel As Integer, ByVal hValue As Long) As Integer
Declare Function Ixud_StartAOVoltage Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wChannel As Integer, ByVal wConfig As Integer, ByVal fSamplingRate As Single, ByVal dwDataCount As Long, ByVal dwCyclyNum As Long, ByRef fValue As Single) As Integer
Declare Function Ixud_StopAO Lib "UniDAQ.dll" (ByVal wBoardNo As Integer, ByVal wChannel As Integer) As Integer
